Tools for RDO-Manager automatic health checks
=============================================

These are tools to perform advanced reporting and role matching based on the
introspection results from `OpenStack Ironic`_ prior to doing an
**RDO-Manager** deployment. This is based on the `AHC`_ concept from the
**enovance edeploy** install method.

.. _OpenStack Ironic: https://wiki.openstack.org/wiki/Ironic
.. _AHC: https://github.com/enovance/edeploy/blob/master/docs/AHC.rst

Usage
-----

Usage documentation is currently provided as part of the
`RDO-Manager documentation`_

.. _RDO-Manager documentation: https://repos.fedorapeople.org/repos/openstack-m/instack-undercloud/html/index.html